@@ -2,7 +2,7 @@
 
 __author__ = """Dave St.Germain"""
 __email__ = 'dave@st.germa.in'
-__version__ = '0.6.0'
+__version__ = '0.9.0'
 
 import time
 from .relay import Manager, Relay
@@ -30,7 +30,7 @@ async def get_anything(anything:str, relays=None, verbose=False, stream=False, o
     elif anything.strip().startswith('{'):
         from json import loads
         query = loads(anything)
-    elif anything.startswith(('nprofile', 'nevent', 'npub', 'nsec', 'nostr:')):
+    elif anything.startswith(('nprofile', 'nevent', 'npub', 'nsec', 'nostr:', 'nrelay')):
         anything = anything.replace('nostr:', '', 1)
         obj = from_nip19(anything)
         if not isinstance(obj, tuple):
@@ -39,9 +39,13 @@ async def get_anything(anything:str, relays=None, verbose=False, stream=False, o
             relays = obj[2] or relays
             if obj[0] == 'nprofile':
                 query = {"kinds": [0], "authors": [obj[1]]}
-            else:
+            elif obj[0] == 'nrelay':
+                return obj[1]
+            elif obj[1]:
                 query = {"ids": [obj[1]]}
                 single_event = True
+            else:
+                raise NotImplementedError(obj[0])
     else:
         query = {"ids": [anything]}
         single_event = True
@@ -74,7 +78,7 @@ async def add_event(relays, event:dict=None, private_key='', kind=1, pubkey='',
     or will be created from the passed in parameters
     """
     if not event:
-        from nostr.key import PrivateKey
+        from .key import PrivateKey
         from .event import Event
         from .util import from_nip19
         created_at = created_at or int(time.time())
