@@ -61,6 +61,10 @@ class Event:
     def is_replaceable(self):
         return self.kind >= 10000 and self.kind < 20000
 
+    @property
+    def is_paramaterized_replaceable(self):
+        return self.kind >= 30000 and self.kind < 40000
+
     @staticmethod
     def serialize(public_key: str, created_at: int, kind: int, tags: "list[list[str]]", content: str) -> bytes:
         data = [0, public_key, created_at, kind, tags, content]
